import time

from iwla import IWLA
from iplugin import IPlugin
from display import *

class IWLADisplayTopDownloads(IPlugin):
    def __init__(self, iwla):
        super(IWLADisplayTopDownloads, self).__init__(iwla)
        self.API_VERSION = 1
        self.requires = ['IWLAPostAnalysisTopDownloads']

    def hook(self):
        top_downloads = self.iwla.getMonthStats()['top_downloads']

        top_downloads = sorted(top_downloads.items(), key=lambda t: t[1], reverse=True)

        index = self.iwla.getDisplayIndex()
        
        table = DisplayHTMLBlockTable('Top Downloads', ['URI', 'Hits'])        
        for (uri, entrance) in top_downloads[:10]:
            table.appendRow([uri, entrance])
        index.appendBlock(table)

        cur_time = self.iwla.getCurTime()
        title = time.strftime('Top Downloads - %B %Y', cur_time)

        filename = 'top_downloads_%d.html' % (cur_time.tm_mon)
        path = '%d/%s' % (cur_time.tm_year, filename)

        page = DisplayHTMLPage(title, path)
        table = DisplayHTMLBlockTable('Top Downloads', ['URI', 'Hit'])        
        for (uri, entrance) in top_downloads:
            table.appendRow([uri, entrance])
        page.appendBlock(table)
                        
        display = self.iwla.getDisplay()
        display.addPage(page)

        block = DisplayHTMLRawBlock()
        block.setRawHTML('<a href=\'%s\'>All Downloads</a>' % (filename))
        index.appendBlock(block)
